% Generate sample datasets
rng(828)
N = 1000;

% Univariate nonparametric regression
Z = -1+2*normcdf(randn(N,1));   % Regressor
U = randn(N,1);                 % Error
Y = 0.1*Z - 0.5*normpdf(0.5*Z) + U;
% Save to mat file
save('Sample1.mat','Y','Z');
% Save to txt file
writematrix([Y Z],'Sample1.txt','Delimiter','tab');
% Save to spreadsheet file
writematrix([Y Z],'Sample1.xlsx');

% Bivariate nonparametric regression
Z = normcdf(randn(N,2));   % Regressor
U = randn(N,1);                 % Error
Y = 0.5*prod(sqrt(Z),2) + 0.5*log(1+5*sum(Z,2)) + U;  
% Save to mat file
save('Sample2.mat','Y','Z');
% Save to txt file
writematrix([Y Z],'Sample2.txt','Delimiter','tab');
% Save to spreadsheet file
writematrix([Y Z],'Sample2.xlsx');

% Two nonparametric regression functions (two goods)
P = 1 + normcdf(randn(N,2)); % Prices
Y = normcdf(randn(N,1));     % Income
PY = [P Y];
Z = normcdf(randn(N,1));     % Controls
U = randn(N,2);              % Errors
Q = (Y./sum(1./P,2))./(P.^2) + repmat(sum(Z,2),1,2) + U;

% Save to mat file
save('Sample3.mat','Q', 'P','Y', 'Z');
% Save to txt file
writematrix([Q P Y Z],'Sample3.txt','Delimiter','tab');
% Save to spreadsheet file
writematrix([Q P Y Z],'Sample3.xlsx');
